==> pl-6.6.6-1.tar.xz: usr/lib/swipl-6.6.6/library/http/INDEX.pl <==
/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index((http_ax_attributes), 2, http_ax, ax).
index((ax_form_attributes), 2, http_ax, ax).
index((html_resource), 2, html_head, html_head).
index((html_requires), 3, html_head, html_head).
index((html_current_resource), 1, html_head, html_head).
index((html), 4, html_quasi_quotations, html_quasiquotations).
index((reply_html_page), 2, html_write, html_write).
index((reply_html_page), 3, html_write, html_write).
index((page), 3, html_write, html_write).
index((page), 4, html_write, html_write).
index((page), 5, html_write, html_write).
index((html), 3, html_write, html_write).
index((html_set_options), 1, html_write, html_write).
index((html_current_option), 1, html_write, html_write).
index((html_post), 4, html_write, html_write).
index((html_receive), 3, html_write, html_write).
index((html_receive), 4, html_write, html_write).
index((xhtml_ns), 4, html_write, html_write).
index((html), 4, html_write, html_write).
index((html_begin), 3, html_write, html_write).
index((html_end), 3, html_write, html_write).
index((html_quoted), 3, html_write, html_write).
index((html_quoted_attribute), 3, html_write, html_write).
index((print_html), 1, html_write, html_write).
index((print_html), 2, html_write, html_write).
index((html_print_length), 2, html_write, html_write).
index((html_meta), 1, html_write, html_write).
index((http_authenticate), 3, authenticate, http_authenticate).
index((http_authorization_data), 2, authenticate, http_authenticate).
index((http_current_user), 3, authenticate, http_authenticate).
index((http_get), 3, http_client, http_client).
index((http_delete), 3, http_client, http_client).
index((http_post), 4, http_client, http_client).
index((http_put), 4, http_client, http_client).
index((http_read_data), 3, http_client, http_client).
index((http_disconnect), 1, http_client, http_client).
index((cookie_remove_client), 1, http_cookie, http_cookie).
index((cookie_remove_all_clients), 0, http_cookie, http_cookie).
index((cookie_current_cookie), 4, http_cookie, http_cookie).
index((cors_enable), 0, http_cors, http_cors).
index((http_reply_dirindex), 3, http_dirindex, http_dirindex).
index((directory_index), 4, http_dirindex, http_dirindex).
index((http_dispatch), 1, http_dispatch, http_dispatch).
index((http_handler), 3, http_dispatch, http_dispatch).
index((http_delete_handler), 1, http_dispatch, http_dispatch).
index((http_reply_file), 3, http_dispatch, http_dispatch).
index((http_redirect), 3, http_dispatch, http_dispatch).
index((http_404), 2, http_dispatch, http_dispatch).
index((http_switch_protocol), 2, http_dispatch, http_dispatch).
index((http_current_handler), 2, http_dispatch, http_dispatch).
index((http_current_handler), 3, http_dispatch, http_dispatch).
index((http_location_by_id), 2, http_dispatch, http_dispatch).
index((http_link_to_id), 3, http_dispatch, http_dispatch).
index((http_reload_with_parameters), 3, http_dispatch, http_dispatch).
index((http_safe_file), 2, http_dispatch, http_dispatch).
index((map_exception_to_http_status), 4, http_exception, http_exception).
index((http_reply_from_files), 3, http_files, http_files).
index((http_read_request), 2, http_header, http_header).
index((http_read_reply_header), 2, http_header, http_header).
index((http_reply), 2, http_header, http_header).
index((http_reply), 3, http_header, http_header).
index((http_reply), 4, http_header, http_header).
index((http_reply), 5, http_header, http_header).
index((http_reply_header), 3, http_header, http_header).
index((http_status_reply), 4, http_header, http_header).
index((http_status_reply), 5, http_header, http_header).
index((http_timestamp), 2, http_header, http_header).
index((http_post_data), 3, http_header, http_header).
index((http_read_header), 2, http_header, http_header).
index((http_parse_header), 2, http_header, http_header).
index((http_parse_header_value), 3, http_header, http_header).
index((http_join_headers), 3, http_header, http_header).
index((http_update_encoding), 3, http_header, http_header).
index((http_update_connection), 4, http_header, http_header).
index((http_update_transfer), 4, http_header, http_header).
index((http_public_url), 2, http_host, http_host).
index((http_public_host_url), 2, http_host, http_host).
index((http_public_host), 4, http_host, http_host).
index((http_current_host), 4, http_host, http_host).
index((reply_json), 1, http_json, http_json).
index((reply_json), 2, http_json, http_json).
index((http_read_json), 2, http_json, http_json).
index((http_read_json), 3, http_json, http_json).
index((http_log_stream), 1, http_log, http_log).
index((http_log), 2, http_log, http_log).
index((http_log_close), 1, http_log, http_log).
index((http_open), 3, http_open, http_open).
index((http_set_authorization), 2, http_open, http_open).
index((openid_login), 1, http_openid, http_openid).
index((openid_logout), 1, http_openid, http_openid).
index((openid_logged_in), 1, http_openid, http_openid).
index((openid_user), 3, http_openid, http_openid).
index((openid_verify), 2, http_openid, http_openid).
index((openid_authenticate), 4, http_openid, http_openid).
index((openid_associate), 3, http_openid, http_openid).
index((openid_associate), 4, http_openid, http_openid).
index((openid_server), 2, http_openid, http_openid).
index((openid_server), 3, http_openid, http_openid).
index((openid_grant), 1, http_openid, http_openid).
index((openid_login_form), 4, http_openid, http_openid).
index((openid_current_url), 2, http_openid, http_openid).
index((openid_current_host), 3, http_openid, http_openid).
index((http_parameters), 2, http_parameters, http_parameters).
index((http_parameters), 3, http_parameters, http_parameters).
index((http_convert_parameter), 4, http_parameters, http_parameters).
index((http_absolute_uri), 2, http_path, http_path).
index((http_absolute_location), 3, http_path, http_path).
index((http_clean_location_cache), 0, http_path, http_path).
index((reply_pwp_page), 3, http_pwp, http_pwp).
index((pwp_handler), 2, http_pwp, http_pwp).
index((serve_files_in_directory), 2, http_server_files, http_server_files).
index((http_set_session_options), 1, http_session, http_session).
index((http_set_session), 1, http_session, http_session).
index((http_session_option), 1, http_session, http_session).
index((http_session_id), 1, http_session, http_session).
index((http_in_session), 1, http_session, http_session).
index((http_current_session), 2, http_session, http_session).
index((http_close_session), 1, http_session, http_session).
index((http_open_session), 2, http_session, http_session).
index((http_session_cookie), 1, http_session, http_session).
index((http_session_asserta), 1, http_session, http_session).
index((http_session_assert), 1, http_session, http_session).
index((http_session_retract), 1, http_session, http_session).
index((http_session_retractall), 1, http_session, http_session).
index((http_session_data), 1, http_session, http_session).
index((http_chunked_open), 3, http_stream, http_stream).
index((stream_range_open), 3, http_stream, http_stream).
index((cgi_open), 4, http_stream, http_stream).
index((cgi_property), 2, http_stream, http_stream).
index((cgi_set), 2, http_stream, http_stream).
index((cgi_discard), 1, http_stream, http_stream).
index((is_cgi_stream), 1, http_stream, http_stream).
index((cgi_statistics), 1, http_stream, http_stream).
index((http_daemon), 0, http_unix_daemon, http_unix_daemon).
index((http_daemon), 1, http_unix_daemon, http_unix_daemon).
index((http_wrapper), 5, httpd_wrapper, http_wrapper).
index((http_current_request), 1, httpd_wrapper, http_wrapper).
index((http_peer), 2, httpd_wrapper, http_wrapper).
index((http_send_header), 1, httpd_wrapper, http_wrapper).
index((http_relative_path), 2, httpd_wrapper, http_wrapper).
index((http_wrap_spawned), 3, httpd_wrapper, http_wrapper).
index((http_spawned), 1, httpd_wrapper, http_wrapper).
index((http_server), 2, http_inetd, inetd_httpd).
index((js_token), 3, javascript_grammar, js_grammar).
index((js_program), 3, javascript_grammar, js_grammar).
index((js_script), 3, javascript, js_write).
index((js_call), 3, javascript, js_write).
index((js_new), 4, javascript, js_write).
index((js_expression), 3, javascript, js_write).
index((js_arg_list), 3, javascript, js_write).
index((js_arg), 3, javascript, js_write).
index((js_args), 3, javascript, js_write).
index((javascript), 4, javascript, js_write).
index((json_read), 2, json, json).
index((json_read), 3, json, json).
index((atom_json_term), 3, json, json).
index((json_write), 2, json, json).
index((json_write), 3, json, json).
index((is_json_term), 1, json, json).
index((is_json_term), 2, json, json).
index((prolog_to_json), 2, json_convert, json_convert).
index((json_to_prolog), 2, json_convert, json_convert).
index((json_object), 1, json_convert, json_convert).
index((mime_pack), 3, mime_pack, mimepack).
index((file_mime_type), 2, mimetype, mimetype).
index((http_current_server), 2, thread_httpd, thread_httpd).
index((http_server_property), 2, thread_httpd, thread_httpd).
index((http_server), 2, thread_httpd, thread_httpd).
index((http_workers), 2, thread_httpd, thread_httpd).
index((http_current_worker), 2, thread_httpd, thread_httpd).
index((http_stop_server), 2, thread_httpd, thread_httpd).
index((http_spawn), 2, thread_httpd, thread_httpd).
index((http_requeue), 1, thread_httpd, thread_httpd).
index((http_close_connection), 1, thread_httpd, thread_httpd).
index((http_current_server), 2, xpce_httpd, xpce_httpd).
index((http_server), 2, xpce_httpd, xpce_httpd).
index((xrds_dom), 2, yadis, yadis).
index((xrds_location), 2, yadis, yadis).

==> pl-7.2.3-1.tar.xz: usr/lib/swipl-7.2.3/library/http/INDEX.pl <==
/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index((http_ax_attributes), 2, http_ax, ax).
index((ax_form_attributes), 2, http_ax, ax).
index((html_resource), 2, html_head, html_head).
index((html_requires), 3, html_head, html_head).
index((html_current_resource), 1, html_head, html_head).
index((html), 4, html_quasi_quotations, html_quasiquotations).
index((reply_html_page), 2, html_write, html_write).
index((reply_html_page), 3, html_write, html_write).
index((page), 3, html_write, html_write).
index((page), 4, html_write, html_write).
index((page), 5, html_write, html_write).
index((html), 3, html_write, html_write).
index((html_set_options), 1, html_write, html_write).
index((html_current_option), 1, html_write, html_write).
index((html_post), 4, html_write, html_write).
index((html_receive), 3, html_write, html_write).
index((html_receive), 4, html_write, html_write).
index((xhtml_ns), 4, html_write, html_write).
index((html), 4, html_write, html_write).
index((html_begin), 3, html_write, html_write).
index((html_end), 3, html_write, html_write).
index((html_quoted), 3, html_write, html_write).
index((html_quoted_attribute), 3, html_write, html_write).
index((print_html), 1, html_write, html_write).
index((print_html), 2, html_write, html_write).
index((html_print_length), 2, html_write, html_write).
index((html_meta), 1, html_write, html_write).
index((http_authenticate), 3, authenticate, http_authenticate).
index((http_authorization_data), 2, authenticate, http_authenticate).
index((http_current_user), 3, authenticate, http_authenticate).
index((http_read_passwd_file), 2, authenticate, http_authenticate).
index((http_write_passwd_file), 2, authenticate, http_authenticate).
index((http_get), 3, http_client, http_client).
index((http_delete), 3, http_client, http_client).
index((http_post), 4, http_client, http_client).
index((http_put), 4, http_client, http_client).
index((http_read_data), 3, http_client, http_client).
index((http_disconnect), 1, http_client, http_client).
index((cookie_remove_client), 1, http_cookie, http_cookie).
index((cookie_remove_all_clients), 0, http_cookie, http_cookie).
index((cookie_current_cookie), 4, http_cookie, http_cookie).
index((cors_enable), 0, http_cors, http_cors).
index((cors_enable), 2, http_cors, http_cors).
index((http_reply_dirindex), 3, http_dirindex, http_dirindex).
index((directory_index), 4, http_dirindex, http_dirindex).
index((http_dispatch), 1, http_dispatch, http_dispatch).
index((http_handler), 3, http_dispatch, http_dispatch).
index((http_delete_handler), 1, http_dispatch, http_dispatch).
index((http_reply_file), 3, http_dispatch, http_dispatch).
index((http_redirect), 3, http_dispatch, http_dispatch).
index((http_404), 2, http_dispatch, http_dispatch).
index((http_switch_protocol), 2, http_dispatch, http_dispatch).
index((http_current_handler), 2, http_dispatch, http_dispatch).
index((http_current_handler), 3, http_dispatch, http_dispatch).
index((http_location_by_id), 2, http_dispatch, http_dispatch).
index((http_link_to_id), 3, http_dispatch, http_dispatch).
index((http_reload_with_parameters), 3, http_dispatch, http_dispatch).
index((http_safe_file), 2, http_dispatch, http_dispatch).
index((map_exception_to_http_status), 4, http_exception, http_exception).
index((http_reply_from_files), 3, http_files, http_files).
index((http_read_request), 2, http_header, http_header).
index((http_read_reply_header), 2, http_header, http_header).
index((http_reply), 2, http_header, http_header).
index((http_reply), 3, http_header, http_header).
index((http_reply), 4, http_header, http_header).
index((http_reply), 5, http_header, http_header).
index((http_reply_header), 3, http_header, http_header).
index((http_status_reply), 4, http_header, http_header).
index((http_status_reply), 5, http_header, http_header).
index((http_timestamp), 2, http_header, http_header).
index((http_post_data), 3, http_header, http_header).
index((http_read_header), 2, http_header, http_header).
index((http_parse_header), 2, http_header, http_header).
index((http_parse_header_value), 3, http_header, http_header).
index((http_join_headers), 3, http_header, http_header).
index((http_update_encoding), 3, http_header, http_header).
index((http_update_connection), 4, http_header, http_header).
index((http_update_transfer), 4, http_header, http_header).
index((http_public_url), 2, http_host, http_host).
index((http_public_host_url), 2, http_host, http_host).
index((http_public_host), 4, http_host, http_host).
index((http_current_host), 4, http_host, http_host).
index((http_log_stream), 1, http_log, http_log).
index((http_log), 2, http_log, http_log).
index((http_log_close), 1, http_log, http_log).
index((http_open), 3, http_open, http_open).
index((http_set_authorization), 2, http_open, http_open).
index((openid_login), 1, http_openid, http_openid).
index((openid_logout), 1, http_openid, http_openid).
index((openid_logged_in), 1, http_openid, http_openid).
index((openid_user), 3, http_openid, http_openid).
index((openid_verify), 2, http_openid, http_openid).
index((openid_authenticate), 4, http_openid, http_openid).
index((openid_associate), 3, http_openid, http_openid).
index((openid_associate), 4, http_openid, http_openid).
index((openid_server), 2, http_openid, http_openid).
index((openid_server), 3, http_openid, http_openid).
index((openid_grant), 1, http_openid, http_openid).
index((openid_login_form), 4, http_openid, http_openid).
index((openid_current_url), 2, http_openid, http_openid).
index((openid_current_host), 3, http_openid, http_openid).
index((http_parameters), 2, http_parameters, http_parameters).
index((http_parameters), 3, http_parameters, http_parameters).
index((http_convert_parameter), 4, http_parameters, http_parameters).
index((http_convert_parameters), 2, http_parameters, http_parameters).
index((http_convert_parameters), 3, http_parameters, http_parameters).
index((http_absolute_uri), 2, http_path, http_path).
index((http_absolute_location), 3, http_path, http_path).
index((http_clean_location_cache), 0, http_path, http_path).
index((reply_pwp_page), 3, http_pwp, http_pwp).
index((pwp_handler), 2, http_pwp, http_pwp).
index((serve_files_in_directory), 2, http_server_files, http_server_files).
index((http_set_session_options), 1, http_session, http_session).
index((http_set_session), 1, http_session, http_session).
index((http_session_option), 1, http_session, http_session).
index((http_session_id), 1, http_session, http_session).
index((http_in_session), 1, http_session, http_session).
index((http_current_session), 2, http_session, http_session).
index((http_close_session), 1, http_session, http_session).
index((http_open_session), 2, http_session, http_session).
index((http_session_cookie), 1, http_session, http_session).
index((http_session_asserta), 1, http_session, http_session).
index((http_session_assert), 1, http_session, http_session).
index((http_session_retract), 1, http_session, http_session).
index((http_session_retractall), 1, http_session, http_session).
index((http_session_data), 1, http_session, http_session).
index((http_chunked_open), 3, http_stream, http_stream).
index((stream_range_open), 3, http_stream, http_stream).
index((multipart_open), 3, http_stream, http_stream).
index((multipart_open_next), 1, http_stream, http_stream).
index((cgi_open), 4, http_stream, http_stream).
index((cgi_property), 2, http_stream, http_stream).
index((cgi_set), 2, http_stream, http_stream).
index((cgi_discard), 1, http_stream, http_stream).
index((is_cgi_stream), 1, http_stream, http_stream).
index((cgi_statistics), 1, http_stream, http_stream).
index((http_daemon), 0, http_unix_daemon, http_unix_daemon).
index((http_daemon), 1, http_unix_daemon, http_unix_daemon).
index((http_wrapper), 5, httpd_wrapper, http_wrapper).
index((http_current_request), 1, httpd_wrapper, http_wrapper).
index((http_peer), 2, httpd_wrapper, http_wrapper).
index((http_send_header), 1, httpd_wrapper, http_wrapper).
index((http_relative_path), 2, httpd_wrapper, http_wrapper).
index((http_wrap_spawned), 3, httpd_wrapper, http_wrapper).
index((http_spawned), 1, httpd_wrapper, http_wrapper).
index((hub_create), 3, hub, hub).
index((hub_add), 3, hub, hub).
index((hub_send), 2, hub, hub).
index((hub_broadcast), 2, hub, hub).
index((current_hub), 2, hub, hub).
index((http_server), 2, http_inetd, inetd_httpd).
index((js_token), 3, javascript_grammar, js_grammar).
index((js_program), 3, javascript_grammar, js_grammar).
index((js_script), 3, javascript, js_write).
index((js_call), 3, javascript, js_write).
index((js_new), 4, javascript, js_write).
index((js_expression), 3, javascript, js_write).
index((js_arg_list), 3, javascript, js_write).
index((js_arg), 3, javascript, js_write).
index((js_args), 3, javascript, js_write).
index((javascript), 4, javascript, js_write).
index((prolog_to_json), 2, json_convert, json_convert).
index((json_to_prolog), 2, json_convert, json_convert).
index((json_object), 1, json_convert, json_convert).
index((mime_pack), 3, mime_pack, mimepack).
index((file_mime_type), 2, mimetype, mimetype).
index((http_current_server), 2, thread_httpd, thread_httpd).
index((http_server_property), 2, thread_httpd, thread_httpd).
index((http_server), 2, thread_httpd, thread_httpd).
index((http_workers), 2, thread_httpd, thread_httpd).
index((http_add_worker), 2, thread_httpd, thread_httpd).
index((http_current_worker), 2, thread_httpd, thread_httpd).
index((http_stop_server), 2, thread_httpd, thread_httpd).
index((http_spawn), 2, thread_httpd, thread_httpd).
index((http_requeue), 1, thread_httpd, thread_httpd).
index((http_close_connection), 1, thread_httpd, thread_httpd).
index((http_enough_workers), 3, thread_httpd, thread_httpd).
index((http_open_websocket), 3, websocket, websocket).
index((http_upgrade_to_websocket), 3, websocket, websocket).
index((ws_send), 2, websocket, websocket).
index((ws_receive), 2, websocket, websocket).
index((ws_receive), 3, websocket, websocket).
index((ws_close), 3, websocket, websocket).
index((ws_open), 3, websocket, websocket).
index((ws_property), 2, websocket, websocket).
index((http_current_server), 2, xpce_httpd, xpce_httpd).
index((http_server), 2, xpce_httpd, xpce_httpd).
index((xrds_dom), 2, yadis, yadis).
index((xrds_location), 2, yadis, yadis).
